==> gulp-taskify-0.0.7.tgz: package/lib/validateTaskObj.js <==
'use strict';

/**
 *
 */
module.exports = function validateTaskObj (taskObj) {

    //
    if (taskObj === null) {
        taskObj = {
            'deps'    : [],
            'exports' : function noop () {}
        };

    //
    } else if (Array.isArray(taskObj)) {
        taskObj = {
            'deps' : taskObj,
            'exports' : function noop () {}
        };

    //
    } else if (typeof taskObj === 'function') {
        taskObj = {
            'deps'    : [],
            'exports' : taskObj
        };

    //
    } else if (typeof taskObj === 'string') {
        taskObj = {
            'deps'    : [taskObj],
            'exports' : function noop () {}
        };
    }

    //
    if (!('deps' in taskObj) && !('exports' in taskObj)) {
        throw new Error('Invalid `taskObj`');
    }

    //
    if ('alias' in taskObj) {

        //
        if (typeof taskObj.alias === 'string') {
            taskObj.alias = [taskObj.alias];
        }

        //
        if (!Array.isArray(taskObj.alias)) {
            throw new Error();
        }

        //
        taskObj.alias.forEach(function (aliasName) {
            if (!aliasName || typeof aliasName !== 'string') {
                throw new Error();
            }
        });

    //
    } else {
        taskObj.alias = [];
    }

    //
    if ('auto' in taskObj) {

        //
        if (taskObj !== true || taskObj !== false) {
            throw new Error();
        }

    //
    } else {
        taskObj.auto = true;
    }

    //
    if (typeof taskObj.deps === 'string') {

        // Empty string
        if (!taskObj.deps) {
            throw new Error();
        }

        //
        taskObj.deps = [taskObj.deps];

    //
    } else if (taskObj.deps === null) {
        taskObj.deps = [];
    }

    //
    if (taskObj.exports === null) {
        taskObj.exports = function noop () {};
    }

    //
    if (!Array.isArray(taskObj.deps)) {
        throw new Error();
    }

    //
    if (typeof taskObj.exports !== 'function') {
        throw new Error();
    }

    //
    return taskObj;

};

==> gulp-taskify-0.0.9.tgz: package/lib/validateTaskObj.js <==
'use strict';

/**
 * @description
 * Lorem ipsum dolor sit amet
 *
 * @requires gulp
 *
 * @param {object} taskObj
 * Lorem ipsum dolor sit amet
 *
 * @returns {object} taskObj
 * Lorem ipsum dolor sit amet
 */
module.exports = function validateTaskObj (taskObj) {

    var
        //
        gulp = require('gulp');

    //
    if (taskObj === null) {
        taskObj = {
            'deps'    : [],
            'exports' : function noop () {}
        };

    //
    } else if (Array.isArray(taskObj)) {
        taskObj = {
            'deps' : taskObj,
            'exports' : function noop () {}
        };

    //
    } else if (typeof taskObj === 'function') {
        taskObj = {
            'deps'    : [],
            'exports' : taskObj
        };

    //
    } else if (typeof taskObj === 'string') {
        taskObj = {
            'deps'    : [taskObj],
            'exports' : function noop () {}
        };
    }

    //
    if ('alias' in taskObj) {

        //
        if (typeof taskObj.alias === 'string') {
            taskObj.alias = [taskObj.alias];
        }

        //
        if (!Array.isArray(taskObj.alias)) {
            throw new Error();
        }

        //
        taskObj.alias.forEach(function (aliasName) {
            if (!aliasName || typeof aliasName !== 'string') {
                throw new Error();
            }
        });

    //
    } else {
        taskObj.alias = [];
    }

    //
    if ('auto' in taskObj) {

        //
        if (taskObj.auto !== true && taskObj.auto !== false) {
            throw new Error();
        }

    //
    } else {
        taskObj.auto = true;
    }

    //
    if (typeof taskObj.deps === 'string') {

        // Empty string
        if (!taskObj.deps) {
            throw new Error();
        }

        //
        taskObj.deps = [taskObj.deps];

    //
    } else if (taskObj.deps == null) {
        taskObj.deps = [];
    }

    //
    if (typeof taskObj.exports === 'string') {
        taskObj.exports = [taskObj.exports];
    }

    //
    if (Array.isArray(taskObj.exports)) {

        //
        taskObj.exports = (function (arr) {
            return function () {
                arr.forEach(function (taskName) {
                    gulp.start(taskName);
                });
            };
        })(taskObj.exports);

    //
    } else if (taskObj.exports == null) {
        taskObj.exports = function noop () {};
    }

    //
    if (!Array.isArray(taskObj.deps)) {
        throw new Error();
    }

    //
    if (typeof taskObj.exports !== 'function') {
        throw new Error();
    }

    //
    return taskObj;

};
